@@ -5,12 +5,12 @@ package Mojolicious::Plugin::NYTProf;
 Mojolicious::Plugin::NYTProf - Auto handling of Devel::NYTProf in your Mojolicious app
 
 =for html
-<a href='https://travis-ci.org/G3S/mojolicious-plugin-nytprof?branch=master'><img src='https://travis-ci.org/G3S/mojolicious-plugin-nytprof.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/G3S/mojolicious-plugin-nytprof?branch=master'><img src='https://coveralls.io/repos/G3S/mojolicious-plugin-nytprof/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/Humanstate/mojolicious-plugin-nytprof?branch=master'><img src='https://travis-ci.org/Humanstate/mojolicious-plugin-nytprof.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/Humanstate/mojolicious-plugin-nytprof?branch=master'><img src='https://coveralls.io/repos/Humanstate/mojolicious-plugin-nytprof/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.19
+0.20
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,7 @@ use File::Temp;
 use File::Which;
 use File::Spec::Functions qw/catfile catdir/;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 METHODS
 
@@ -412,7 +412,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation
 please raise an issue / pull request:
 
-    https://github.com/G3S/mojolicious-plugin-nytprof
+    https://github.com/Humanstate/mojolicious-plugin-nytprof
 
 =cut
 
